@@ -6,7 +6,7 @@ use IO::All;
 use List::Util 'uniq';
 use namespace::autoclean;
 
-our $VERSION = '0.1.6'; # VERSION:
+our $VERSION = '0.1.7'; # VERSION:
 # ABSTRACT: used to submit a batch of task to Torque cluster
 
 
@@ -108,12 +108,12 @@ sub execute {
       sleep 1;
       my ($name, $cpu, $cmd, $priority) = ($task->name, $task->cpu, $task->cmd, $task->priority);
       my $pid = $pm->start and next DATA_LOOP;
-      say "CMD1:$cmd will be submitted\n";
+      say "$name will be submitted\n";
       $task->qsub->wait;
-      say "CMD2:$cmd  finished\n";
+      say "$name  finished\n";
       my ($stat, $job_id, $sh_name) = ($task->job_stat, $task->job_id, $task->_sh_name);
       my $content = "$name\t$cpu\t$priority\t$sh_name\t$job_id\t$stat\t$cmd\n";
-      say "$content";
+      #say "$content";
       #my $log_name = $self->name . ".log";
       #io($log_name)->lock->append($content)->unlock;
       $self->_log->lock->append($content)->unlock;
@@ -144,7 +144,7 @@ Bioinfo::PBS::Queue - used to submit a batch of task to Torque cluster
 
 =head1 VERSION
 
-version 0.1.6
+version 0.1.7
 
 =head1 SYNOPSIS
 
